@@ -7,7 +7,7 @@ use warnings 'all';
 ###########################################################################
 # METADATA
 our $AUTHORITY = 'cpan:DOUGDUDE';
-our $VERSION   = '0.002_002';
+our $VERSION   = '0.001';
 
 ###########################################################################
 # MOOSE
@@ -30,6 +30,7 @@ use HTML::HTML5::Parser 0.03;
 use List::MoreUtils 0.07;
 use Net::SAJAX 0.102;
 use Readonly 1.03;
+use URI;
 use WWW::USF::Directory::Entry;
 use WWW::USF::Directory::Entry::Affiliation;
 use WWW::USF::Directory::Exception;
@@ -172,7 +173,6 @@ sub search {
 
 	# Get the advanced search parameters
 	my ($campus, $college, $department) =
-		map { length($_) ? $_ : $args{$_} } # Restore to original if it didn't exist
 		map { $self->_advanced_search_parameter_id($_ => $args{$_}) }
 		qw(campus college department);
 
@@ -313,7 +313,7 @@ sub _build_sajax {
 
 	# This will return a SAJAX object with default options
 	return Net::SAJAX->new(
-		url => $self->directory_url->clone,
+		url => URI->new($self->directory_url->clone),
 	);
 }
 
@@ -328,20 +328,17 @@ sub _clean_node_text {
 	# Find all the line breaks
 	foreach my $br ($node->getElementsByTagName('br')) {
 		# Replace the line breaks with a text node with a new line
-		$br->replaceNode($node->ownerDocument->createTextNode('{NEWLINE}'));
+		$br->replaceNode($node->ownerDocument->createTextNode("\n"));
 	}
 
 	# Get the text of the node (make sure it is native UTF-8)
 	my $text = Encode::encode_utf8($node->textContent);
 
 	# Transform all the horizontal space into ASCII spaces
-	$text =~ s{\s+}{ }gmsx;
+	$text =~ s{\h+}{ }gmsx;
 
 	# Truncate leading and trailing horizontal space
-	$text =~ s{^\s+|\s+$}{}gmsx;
-
-	# Change the new-lines back
-	$text =~ s{{NEWLINE}}{\n}gmsx; # Because perl < 5.10 cannot do \v and \h
+	$text =~ s{^\h+|\h+$}{}gmsx;
 
 	# Return the text
 	return $text;
@@ -467,7 +464,7 @@ sub _table_row_to_entry {
 
 	if (exists $row{given_name}) {
 		# Split on vertical whitespace
-		my @given_names = split m{[\r\n]+}msx, $row{given_name};
+		my @given_names = split m{\v+}msx, $row{given_name};
 
 		# The first two given names are as follows
 		my ($first_name, $middle_name) = @given_names;
@@ -485,7 +482,7 @@ sub _table_row_to_entry {
 
 	if (exists $row{affiliation}) {
 		# There could be zero or more affiliations seperated by vertical space
-		my @affiliations = split m{\s*[\r\n]+\s*}msx, delete $row{affiliation};
+		my @affiliations = split m{\h*\v+\h*}msx, delete $row{affiliation};
 
 		# Change the affiliation to objects
 		foreach my $affiliation (@affiliations) {
@@ -500,7 +497,7 @@ sub _table_row_to_entry {
 	foreach my $value (values %row) {
 		if (ref $value eq q{}) {
 			# A string, so remove vertical whitespace
-			$value =~ s{\s*[\r\n]+\s*}{ }gmsx;
+			$value =~ s{\h*\v+\h*}{ }gmsx;
 		}
 	}
 
@@ -536,7 +533,7 @@ WWW::USF::Directory - Access to USF's online directory
 
 =head1 VERSION
 
-Version 0.002_002
+Version 0.001
 
 =head1 SYNOPSIS
 
@@ -731,8 +728,6 @@ the server that were not known when the module was written.
 
 =item * L<Net::SAJAX> 0.102
 
-=item * L<Readonly> 1.03
-
 =item * L<namespace::clean> 0.04
 
 =back
