@@ -7,7 +7,7 @@ use warnings 'all';
 ###########################################################################
 # METADATA
 our $AUTHORITY = 'cpan:DOUGDUDE';
-our $VERSION   = '0.002_002';
+our $VERSION   = '0.001';
 
 ###########################################################################
 # MOOSE
@@ -129,7 +129,7 @@ WWW::USF::Directory::Entry - An entry in the USF online directory
 
 =head1 VERSION
 
-Version 0.002_002
+Version 0.001
 
 =head1 SYNOPSIS
 
@@ -174,8 +174,7 @@ L</ATTRIBUTES> section).
 
 =head2 affiliations
 
-This is the list of affilitations to USF as
-L<WWW::USF::Directory::Entry::Affiliation> objects.
+This is the list of affilitations to USF.
 
 =head2 campus
 
